==> larus_board-0.8.36.tbz: larus_board-0.8.36/setup/lang.en.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$XFSLANG = array(
'please_activate_javascript'=>'Please activate Javascript in your browser to ensure setup is working correctly!',
'begin'=>'Begin',
'precheck'=>'Set Path',
'select'=>'Set Parameter',
'end'=>'End',
'license_information'=>'License Information',
'notice'=>'Notice',
'development_version'=>'This software is a development version and is not intended for production use! It likely
contains undiscovered bugs and issues which sometimes even result in data loss.',
'license'=>'This software is "Free Software" as defined by the
<a href="http://www.gnu.org/philosophy/free-sw.html" target="_blank">Free Software Foundation</a>
in February 1986 and grant basically four freedoms to any user who got a copy:
<ul>
<li>Freedom 0: The freedom to run the program for any purpose.</li>
<li>Freedom 1: The freedom to study and modify the program.</li>
<li>Freedom 2: The freedom to copy the program so you can help your neighbor.</li>
<li>Freedom 3: The freedom to improve the program, and release your improvements to the public,
so that the whole community benefits.</li>
</ul><hr />
<strong>Modified BSD License</strong><br />
Copyright (c) 2008, The Larus Board Team<br />
All rights reserved.<br /><br />
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
following conditions are met:
<ul>
<li>Redistributions of source code must retain the above copyright notice, this list of conditions and the
following disclaimer.</li>
<li>Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
following disclaimer in the documentation and/or other materials provided with the distribution.</li>
<li>Neither the name of "The Larus Board Team" nor the names of its contributors may be used to endorse or promote
products derived from this software without specific prior written permission.</li>
</ul>
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.<hr />
<strong>Creative Commons Attribution-Share Alike 3.0</strong><br />
You are free:<ul>
<li>to Share - to copy, distribute and transmit the work</li>
<li>to Remix - to adapt the work</li>
</ul>
Under the following conditions:<ul>
<li>Attribution. You must attribute the work in the manner specified by the
author or licensor (but not in any way that suggests that they endorse
you or your use of the work). What does "Attribute this work" mean?
The page you came from contained embedded licensing metadata, including
how the creator wishes to be attributed for re-use. You can use the HTML
here to cite the work. Doing so will also include metadata on your page
so that others can find the original work as well.</li>
<li>Share Alike. If you alter, transform, or build upon this work, you may
distribute the resulting work only under the same, similar or a
compatible license.</li>
<li>For any reuse or distribution, you must make clear to others the license
terms of this work. The best way to do this is with a link to this web page.</li>
<li>Any of the above conditions can be waived if you get permission from the
copyright holder.</li>
<li>Nothing in this license impairs or restricts the author\'s moral rights.</li>
</ul>',
'i_agree'=>'I agree to these terms',
'php_version'=>'PHP Version',
'php_module'=>'PHP Module',
'php_module_mandatory'=>'mandatory',
'php_module_optional'=>'optional',
'req_explain_php_version'=>'At least version 5.2.0 is required of PHP to run "Larus Board"',
'req_explain_php_module_pcre'=>'PCRE extracts patterns from strings and is widely used',
'req_explain_php_module_filter'=>'This is used to filter user inputs from dangerous contents',
'req_explain_php_module_pdo'=>'PDO provides a common base for database communication',
'req_explain_php_module_pdo_mysql'=>'A PDO driver for MySQL',
'req_explain_php_module_pdo_pgsql'=>'A PDO driver for PostgreSQL',
'req_explain_php_module_session'=>'Stores user data during a login session',
'req_explain_php_module_date'=>'Computes different timezones and date formats',
'req_explain_php_module_gd'=>'Paints dynamic bitmap images',
'req_explain_php_module_zlib'=>'Compress output for clients',
'req_explain_php_module_hash'=>'Allows using more secure hashes for password storage',
'req_explain_php_module_mcrypt'=>'Provides cryptography routines for en-/decryption',
'req_explain_php_module_suhosin'=>'Enhances PHP\'s core security',
'back'=>'Back',
'no'=>'no',
'yes'=>'yes',
'initial_environment_detection'=>'Initial Environment Detection',
'detected_root_path'=>'Detected Path to "Public"',
'detected_root_uri'=>'Detected URI to "Public"',
'if_correct_go_on'=>'If anything is correct, please click here to continue...',
'repair_options'=>'Repair Options',
'root_uri'=>'Root URI of "Public"',
'root_path'=>'Root Path of "Private"',
'directory_not_writeable'=>'Notice: Folder "%s" is not writable!',
'file_not_writeable'=>'Notice: File "%s" is not writable!',
'setup_type'=>'What yould you like to do?',
'source_database'=>'Database Information for Source Forum-Software',
'target_database'=>'Database Information for Larus Board',
'install'=>'Fresh/Repair Installation',
'update'=>'Update Existing Installation',
'convert'=>'Convert from Other Software',
'installation_complete'=>'Installation is complete',
'db_type'=>'Database Type',
'db_host'=>'Database Host',
'db_username'=>'Database Username',
'db_password'=>'Database Password',
'db_name'=>'Database Name',
'db_prefix'=>'Database Table Prefix',
'guest_username'=>'ID of "Guest User"',
'admin_name'=>'Executive User Name (3-32 chars, Install only)',
'admin_password'=>'Executive User Password (5+ chars, Install only)',
'configuration_file_not_writeable'=>'Your configuration file cannot be written to!',
'source_forum_software'=>'Select software to convert from',
'mysql_is_too_old'=>'Your MySQL-Version is too old - upgrade at least to 4.1.0!',
'explain_password_rehashing'=>'You can assign a new password to each user here. It will be sent to the stored mail address.<br />
If this process aborts by timeout, just reload the page. All missing passwords will be refreshed until complete.',
'database_integrity_check_step'=>'<strong>Begin to perform step "%s" from queue</strong><br />',
'database_integrity_skip_step'=>'<strong>Skipping step "%s" as already done</strong><br />',
'dic_insert_acl'=>'&nbsp;&nbsp;&nbsp;· Inserted new ACL for action "%s" having Group-ID %d<br />',
'dic_update_post_data'=>'&nbsp;&nbsp;&nbsp;· Set User-ID to 1 for Posting %d (Data Section)<br />',
'dic_update_post_meta'=>'&nbsp;&nbsp;&nbsp;· Set User-ID to 1 for Posting %d (Meta Section)<br />',
'dic_update_user_group'=>'&nbsp;&nbsp;&nbsp;· Set Group-ID to 1 for User-ID %d<br />',
'database_integrity_check_complete'=>'Your database integrity has been verified.'
);
?>

==> larus_board-0.9.0.tbz: larus_board-0.9.0/setup/lang.en.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$XFSLANG = array(
'please_activate_javascript'=>'Please activate Javascript in your browser to ensure setup is working correctly!',
'begin'=>'Begin',
'precheck'=>'Set Path',
'select'=>'Set Parameter',
'end'=>'End',
'license_information'=>'License Information',
'notice'=>'Notice',
'development_version'=>'This software is a development version and is not intended for production use! It likely
contains undiscovered bugs and issues which sometimes even result in data loss.',
'license'=>'This software is "Free Software" as defined by the
<a href="http://www.gnu.org/philosophy/free-sw.html" target="_blank">Free Software Foundation</a>
in February 1986 and grant basically four freedoms to any user who got a copy:
<ul>
<li>Freedom 1: The freedom to run the program for any purpose.</li>
<li>Freedom 2: The freedom to study and modify the program.</li>
<li>Freedom 3: The freedom to copy the program so you can help your neighbor.</li>
<li>Freedom 4: The freedom to improve the program, and release your improvements to the public,
so that the whole community benefits.</li>
</ul><hr />
<strong>Modified BSD License</strong><br />
Copyright (c) 2008, The Larus Board Team<br />
All rights reserved.<br /><br />
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
following conditions are met:
<ul>
<li>Redistributions of source code must retain the above copyright notice, this list of conditions and the
following disclaimer.</li>
<li>Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
following disclaimer in the documentation and/or other materials provided with the distribution.</li>
<li>Neither the name of "The Larus Board Team" nor the names of its contributors may be used to endorse or promote
products derived from this software without specific prior written permission.</li>
</ul>
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.<hr />
<strong>Creative Commons Attribution-Share Alike 3.0</strong><br />
You are free:<ul>
<li>to Share - to copy, distribute and transmit the work</li>
<li>to Remix - to adapt the work</li>
</ul>
Under the following conditions:<ul>
<li>Attribution. You must attribute the work in the manner specified by the
author or licensor (but not in any way that suggests that they endorse
you or your use of the work). What does "Attribute this work" mean?
The page you came from contained embedded licensing metadata, including
how the creator wishes to be attributed for re-use. You can use the HTML
here to cite the work. Doing so will also include metadata on your page
so that others can find the original work as well.</li>
<li>Share Alike. If you alter, transform, or build upon this work, you may
distribute the resulting work only under the same, similar or a
compatible license.</li>
<li>For any reuse or distribution, you must make clear to others the license
terms of this work. The best way to do this is with a link to this web page.</li>
<li>Any of the above conditions can be waived if you get permission from the
copyright holder.</li>
<li>Nothing in this license impairs or restricts the author\'s moral rights.</li>
</ul>',
'i_agree'=>'I agree to these terms',
'php_version'=>'PHP Version',
'php_module'=>'PHP Module',
'php_module_mandatory'=>'mandatory',
'php_module_optional'=>'optional',
'req_explain_php_version'=>'At least version 5.2.0 is required of PHP to run "Larus Board"',
'req_explain_php_module_pcre'=>'PCRE extracts patterns from strings and is widely used',
'req_explain_php_module_filter'=>'This is used to filter user inputs from dangerous contents',
'req_explain_php_module_pdo'=>'PDO provides a common base for database communication',
'req_explain_php_module_pdo_mysql'=>'A PDO driver for MySQL',
'req_explain_php_module_pdo_pgsql'=>'A PDO driver for PostgreSQL',
'req_explain_php_module_session'=>'Stores user data during a login session',
'req_explain_php_module_date'=>'Computes different timezones and date formats',
'req_explain_php_module_gd'=>'Paints dynamic bitmap images',
'req_explain_php_module_zlib'=>'Compress html output for clients/browsers',
'req_explain_php_module_hash'=>'Allows using more secure hashes for password storage',
'req_explain_php_module_mcrypt'=>'Provides cryptography routines for en-/decryption',
'req_explain_php_module_simplexml'=>'Easy method to parse XML formatted files like RSS feeds',
'req_explain_php_module_suhosin'=>'Enhances PHP\'s core security',
'back'=>'Back',
'no'=>'no',
'yes'=>'yes',
'initial_environment_detection'=>'Initial Environment Detection',
'detected_root_path'=>'Detected Path to "Public"',
'detected_root_uri'=>'Detected URI to "Public"',
'if_correct_go_on'=>'If anything is correct, please click here to continue...',
'repair_options'=>'Repair Options',
'root_uri'=>'Root URI of "Public"',
'root_path'=>'Root Path of "Private"',
'folder_not_writeable'=>'Notice: Folder "%s" is not writable!',
'file_not_writeable'=>'Notice: File "%s" is not writable!',
'setup_type'=>'What yould you like to do?',
'source_database'=>'Database Information for Source Forum-Software',
'target_database'=>'Database Information for "Larus Board"',
'install'=>'Fresh/Repair Installation',
'update'=>'Update Existing Installation',
'convert'=>'Convert from Other Software',
'installation_complete'=>'Installation is complete',
'reset_a_password'=>'Reset a password',
'rebuild_passwords'=>'Rebuild all passwords',
'edit_configuration'=>'Edit configuration',
'purge_local_cache'=>'Purge local cache',
'verify_database_integrity'=>'Verify database integrity',
'db_type'=>'Database Type',
'db_host'=>'Database Host',
'db_username'=>'Database Username',
'db_password'=>'Database Password (must not be empty)',
'db_name'=>'Database Name',
'db_prefix'=>'Database Table Prefix',
'guest_username'=>'ID of "Guest User"',
'admin_name'=>'Executive User Name (3-32 chars, Install only)',
'admin_password'=>'Executive User Password (5+ chars, Install only)',
'database_connection_check'=>'Checking database connection',
'database_server_version'=>'The server software version is',
'configuration_file_not_writeable'=>'Your configuration file cannot be written to!',
'source_forum_software'=>'Select software to convert from',
'mysql_is_too_old'=>'Your MySQL-Version is too old - upgrade at least to 4.1.0!',
'explain_password_rehashing'=>'You can assign a new password to each user here. It will be sent to the
stored mail address.<br />
If this process aborts by timeout, just reload the page. All missing passwords will be refreshed until
complete.',
'new_password'=>'New Password',
'password_rehashing_complete'=>'Your user passwords are now regenerated.',
'explain_verify_database_integrity'=>'You can verify the integrity of your database here. It validates
relationship between the tables.<br />
If this process aborts by timeout, just reload the page. All missing steps will be done until complete.',
'database_integrity_check_step'=>'<strong>Begin to perform step "%s" from queue</strong><br />',
'database_integrity_skip_step'=>'<strong>Skipping step "%s" as already done</strong><br />',
'dic_insert_acl'=>'&nbsp;&nbsp;&nbsp;· Inserted new ACL for action "%s" having Group-ID %d<br />',
'dic_update_post_data'=>'&nbsp;&nbsp;&nbsp;· Set User-ID to 1 for Posting %d (Data Section)<br />',
'dic_update_post_meta'=>'&nbsp;&nbsp;&nbsp;· Set User-ID to 1 for Posting %d (Meta Section)<br />',
'dic_update_user_group'=>'&nbsp;&nbsp;&nbsp;· Set Group-ID to 1 for User-ID %d<br />',
'database_integrity_check_complete'=>'Your database integrity has been verified.',
'explain_reset_a_password'=>'You can reset the password of a single user here.',
'username_or_userid'=>'Username or numerical ID',
'password'=>'New Password',
'please_repeat'=>'Please repeat',
'passwords_are_not_equal'=>'Both passwords are not equal',
'reset_a_password_complete'=>'The user password is now changed.',
'could_not_set_new_password'=>'Sorry, could not set the new password!',
'explain_edit_configuration'=>'You can change your configuration settings here.<br />Please be careful
as the values will not be verified.',
'configuration_edit_complete'=>'Editing your configuration is complete.',
'explain_purge_local_caches'=>'You can purge your entire local file cache here. It will automatically
be rebuild as neccessary.',
'purging_local_caches_complete'=>'Your local file cache is now completely empty.'
);
?>
